@@ -3,9 +3,9 @@ from .saucenao_api import SauceNao
 
 __author__ = 'nomnoms12'
 __copyright__ = 'Copyright 2020, Taiga.sh Development'
-__credits__ = ['nomnoms12', 'FujiMakoto', 'rubinduck']
+__credits__ = ['nomnoms12', 'FujiMakoto', 'rubinduck', 'spoopcity']
 __license__ = 'GNU General Public License v3.0'
-__version__ = '2.2.0'
+__version__ = '2.3.1'
 __maintainer__ = 'nomnoms12'
 __email__ = 'alexander.ign0918@gmail.com'
 __status__ = 'Production'
